#
# spec file for package ddcutil-service
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Michael Hamilton <michael@actrix.gen.nz>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ddcutil-service
Version:        1.0.14
Release:        1.1
Summary:        D-Bus service for libddcutil VESA DDC Monitor Virtual Control Panel
License:        GPL-2.0-or-later
%if %{defined fedora_version}
Group:          Hardware/Other
%endif
%if %{defined suse_version}
Group:          System/GUI/Other
%endif
URL:            https://github.com/digitaltrails/ddcutil-service
Source0:        https://github.com/digitaltrails/ddcutil-service/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libddcutil-devel >= 1.4.0
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.40
%if %{defined fedora_version}
Requires:       dbus-1-daemon
%endif
%if %{defined suse_version}
Requires:       dbus-1
%endif
Recommends:     ddcutil-i2c-udev-rules

%description
ddcutil-service is D-Bus service wrapper for libddcutil which
implements the VESA DDC Monitor Control Command Set. In general,
most things that can be controlled using a monitor's on-screen
display can be controlled by this service.

%prep
%autosetup

%build
%make_build

%install
install -d -m 0755 %{buildroot}%{_bindir} \
                   %{buildroot}%{_mandir}/man1/ \
                   %{buildroot}%{_mandir}/man7/ \
                   %{buildroot}%{_datadir}/%{name}/examples \
                   %{buildroot}%{_datadir}/dbus-1/services
install -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}
install -m 0644 com.ddcutil.DdcutilService.service %{buildroot}%{_datadir}/dbus-1/services/
install -m 0755 examples/* %{buildroot}%{_datadir}/%{name}/examples/
install -m 0644 %{name}.1 %{buildroot}%{_mandir}/man1/
install -m 0644 %{name}.7 %{buildroot}%{_mandir}/man7/
install -m 0644 -D -t %{buildroot}%{_prefix}/lib/modules-load.d/ i2c-dev/%{name}.conf

# The post modprobe is helpful for the user, but not really necessary, don't error if it fails
%post
%{_prefix}/sbin/modprobe i2c-dev ||:

%files
%license COPYING
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/examples
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_bindir}/%{name}
%{_datadir}/dbus-1/services/com.ddcutil.DdcutilService.service
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man7/%{name}.7%{?ext_man}
%{_datadir}/%{name}/examples/dbus-enable-info-logging.bash
%{_datadir}/%{name}/examples/dbus-send-query-brightness.bash
%{_datadir}/%{name}/examples/ddcutil-dasbus-client.py
%{_datadir}/%{name}/examples/ddcutil-dasbus-signal-receiver.py
%{_datadir}/%{name}/examples/ddcutil-qtdbus-client.py
%{_datadir}/%{name}/examples/ddcutil-qtdbus-signal-receiver.py
%{_datadir}/%{name}/examples/busctl.bash
%{_datadir}/%{name}/examples/dbus-enable-signals.bash
%{_datadir}/%{name}/examples/dbus-set-polling-interval.bash
%{_datadir}/%{name}/examples/dbus-send-introspect.bash
%{_datadir}/%{name}/examples/dbus-send-detect.bash
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/%{name}.conf

%changelog
* Sat Mar  8 2025 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.14
  - A hotplug and DPMS tidy up to accommodate quirks exhibited by drivers, GPUs and monitors.
  - Default to libddcutil event detection for libddcutil >= 2.2 (for faster response to changes).
  - Add option --prefer-libddcutil-events as a better name for deprecated option --prefer-drm.
  - Deprecate option --prefer-drm as it's name is misleading.
  - Add option --disable-connectivity-signals to allow connectivity signals to be turned off.
  - Add options --disable-hotplug-polling and --disable-dpms-polling to accommodate quirky monitors.
  - Always internally poll for DPMS changes (DPMS is not covered by libddcutil events).
  - Add method ListDetected to take advantage of hotplug detection in libddcutil >= 2.2.
  - Add the list command to ddcutil-client to provide access to the new ListDetected method.
  - Add wait, wait-connection-change, and wait-vcp-change commands to ddcutil-client.
  - Log more information when get_vcp fails.
* Wed Nov 27 2024 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.12
  - Return the error status-code if enable_ddca_watch_displays fails - was returning OK even on failure.
* Thu Aug 22 2024 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.11
  - Alter the detect-function for ddcutil 2.5.1 (generates more logging/warning info).
  - Add a DETECT_ALL option to control whether disabled/powered-off VDU's are to be included in the results from detect.
  - Reduce the number of messages generated when polling for hotplug events.
  - Fixes to API documentation.
* Thu Jun 13 2024 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.9
  - Fixed a GetCapabilitiesMetadata bug that caused some VCP features to lack metadata values.
  - Fixed the return of feature-name and feature-description from GetVcpMetadata.
  - Fixed potential hot-plug/DPMS polling memory leaks and simplified event locking.
  - Recoded hot-plug/DPMS polling to avoid a potential libddcutil assertion failure.
  - Fixed code/doc typos, improved code readability/structure, reduced IDE warnings.
  - Updated documentation to caution against excessive updates when coding loops, as this may impact VDU NVRAM lifespan.
  - Updated documentation to caution against experimenting with non-standard features, as it may risk damage to the VDU.
* Thu May 16 2024 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.7
  - Slightly improved setvcp diagnostics.
  - Fix methods failing with return code DDCRC_OTHER (-3022) when only some i2c devices are accessible.
* Mon Apr 29 2024 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.6
  - Add SetVcp/SetVcpWithContext NO_VERIFY (no retry) flag option.
  - Match the behaviour of the ddcutil command, default to verify-and-retry for all set-vcp method calls.
  - Default to verify-and-retry for all libddcutil versions.
  - Replace the stateful DdcutilVerifySetVcp property with the stateless NO_VERIFY flag.
  - Fix the ServiceFlagOptions property so that it lists all flag options.
  - Check the status returned by libddcutil ddca_init() and exit on error to prevent any inconsistent behaviour.
  - Cleanup the --prefer-polling and --prefer-drm options to make them consistent with each other.
* Fri Apr 12 2024 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.4
  - Provide an API flag RETURN_RAW_VALUES which disables GetVcp high-byte masking of Simple Non-Continuous features.
  - Provide the --return-raw-values command line option for the same purpose.
* Mon Apr  1 2024 Michael Hamilton <michael@actrix.gen.nz>
- 1.0.3
  - Reduce unnecessary logging.
  - Improve the description of the service's signals in ddcutil-service.1.
  - Correct the typo in option name --perfer-drm (it was mistakenly called --prefer-dma).
  - For simple VCP-features, only return the low-byte, for some VDUs the high-byte might contain junk.
* Thu Feb 29 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.0.2
  - Added VcpValueChanged D-Bus signal which triggers if the SetVcp method succeeds. This is to allow
    multiple clients to be aware of changes made by each.
  - Added SetVcpWithContext which accepts a client-context to be returned with the VcpValueChanged signal.
  - ServiceEmitSignals renamed to ServiceEmitConnectivitySignals to avoid confusion.
  - Command line option --emit-signals renamed to --emit-connectivity-signals for the same reason.
  - Fix ServiceEmitSignals property assignment so that it correctly toggles hotplug signals.
  - Fix hotplug polling so that it remains an option no matter what version of libddcutil is in use.
- Version 1.0.1
  - Use gcc with -Wformat-security for safety and to match Arch and Ubuntu defaults.
  - Calling ddca_init() before verify_i2c() to fix runtime error for libddcutil >= 2.1.
* Thu Jan 18 2024 Michael Hamilton <michael@actrix.gen.nz>
- Version 1.0.0
  * Added an optional D-Bus interface to ddcutil for up 10x faster response times.
